netapp_ontap.resources.gcp_kms API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.gcp_kms`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

Google Cloud Key Management Services is a cloud key management service (KMS) that provides a secure store for encryption keys. This feature allows ONTAP to securely store its encryption keys using Google Cloud KMS. In order to use Google Cloud KMS with ONTAP, a user must first deploy a Google Cloud application with appropriate access to the Google Cloud KMS and then provide ONTAP with the necessary details, such as, project ID, key ring name, location, key name and application credentials to allow ONTAP to communicate with the deployed Google Cloud application.

## Examples

### Enabling GCKMS for an SVM

The following example shows how to enable GCKMS at the SVM-scope. Note the return_records=true query parameter is used to obtain the newly created key manager configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms()
        resource.svm.uuid = "f36ff553-e713-11ea-bd56-005056bb4222"
        resource.project_id = "testProj"
        resource.key_ring_name = "testKeyRing"
        resource.key_ring_location = "global"
        resource.key_name = "key1"
        resource.application_credentials = "myAppCred"
        resource.post(hydrate=True)
        print(resource)

Try it out

    GcpKms(
        {
            "key_ring_location": "global",
            "uuid": "f72098a2-e908-11ea-bd56-005056bb4222",
            "_links": {
                "self": {
                    "href": "/api/security/gcp-kms/f72098a2-e908-11ea-bd56-005056bb4222"
                }
            },
            "key_name": "key1",
            "key_ring_name": "testKeyRing",
            "svm": {"name": "vs0", "uuid": "f36ff553-e713-11ea-bd56-005056bb4222"},
            "project_id": "testProj",
        }
    )

### Retrieving all GCKMS configurations

The following example shows how to retrieve all GCKMS configurations.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(GcpKms.get_collection(fields="*")))

Try it out

    [
        GcpKms(
            {
                "key_ring_location": "global",
                "uuid": "f72098a2-e908-11ea-bd56-005056bb4222",
                "scope": "svm",
                "_links": {
                    "self": {
                        "href": "/api/security/gcp-kms/f72098a2-e908-11ea-bd56-005056bb4222"
                    }
                },
                "key_name": "key1",
                "key_ring_name": "testKeyRing",
                "svm": {"name": "vs0", "uuid": "f36ff553-e713-11ea-bd56-005056bb4222"},
                "project_id": "testProj",
                "state": {
                    "cluster_state": False,
                    "message": "The Google Cloud Key Management Service key protection is unavailable on the following nodes: cluster1-node1.",
                    "code": 65537708,
                },
            }
        )
    ]

### Retrieving a specific GCKMS configuration

The following example shows how to retrieve information for a specific GCKMS configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.get(fields="*")
        print(resource)

Try it out

    GcpKms(
        {
            "key_ring_location": "global",
            "uuid": "f72098a2-e908-11ea-bd56-005056bb4222",
            "scope": "svm",
            "_links": {
                "self": {
                    "href": "/api/security/gcp-kms/f72098a2-e908-11ea-bd56-005056bb4222"
                }
            },
            "key_name": "key1",
            "key_ring_name": "testKeyRing",
            "svm": {"name": "vs0", "uuid": "f36ff553-e713-11ea-bd56-005056bb4222"},
            "project_id": "testProj",
            "state": {
                "cluster_state": False,
                "message": "The Google Cloud Key Management Service key protection is unavailable on the following nodes: cluster1-node1.",
                "code": 65537708,
            },
        }
    )

### Updating the application credentials of a specific GCKMS configuration

The following example shows how to update the application credentials for a specific GCKMS configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.application_credentials = "newAppCred"
        resource.patch()

### Deleting a specific GCKMS configuration

The following example shows how to delete a specific GCKMS configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.delete()

### Restoring keys from KMIP server

The following example shows how to retore keys for a GCKMS configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms(uuid="33820b57-ec90-11ea-875e-005056bbf3f0")
        resource.restore()

## Classes

`class GcpKms (*args, **kwargs)`

  Allows interaction with GcpKms objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves Google Cloud KMS configurations for all clusters and SVMs.

    ### Related ONTAP commands

    - `security key-manager external gcp show`

    ### Learn more

    - `DOC /security/gcp-kms`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a Google Cloud KMS configuration.

    ### Related ONTAP commands

    - `security key-manager external gcp disable`

    ### Learn more

    - `DOC /security/gcp-kms`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves Google Cloud KMS configurations for all clusters and SVMs.

    ### Related ONTAP commands

    - `security key-manager external gcp show`

    ### Learn more

    - `DOC /security/gcp-kms`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves Google Cloud KMS configurations for all clusters and SVMs.

    ### Related ONTAP commands

    - `security key-manager external gcp show`

    ### Learn more

    - `DOC /security/gcp-kms`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the Google Cloud KMS configuration.

    ### Required properties

    - `application_credentials` - New credentials used to verify the application's identity to the Google Cloud KMS.

    ### Related ONTAP commands

    - `security key-manager external gcp modify`

    ### Learn more

    - `DOC /security/gcp-kms`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a Google Cloud KMS configuration.

    ### Related ONTAP commands

    - `security key-manager external gcp disable`

    ### Learn more

    - `DOC /security/gcp-kms`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the Google Cloud KMS configuration for the SVM specified by the UUID.

    ### Related ONTAP commands

    - `security key-manager external gcp show`

    ### Learn more

    - `DOC /security/gcp-kms`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the Google Cloud KMS configuration.

    ### Required properties

    - `application_credentials` - New credentials used to verify the application's identity to the Google Cloud KMS.

    ### Related ONTAP commands

    - `security key-manager external gcp modify`

    ### Learn more

    - `DOC /security/gcp-kms`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Configures the Google Cloud KMS configuration for the specified SVM.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create a Google Cloud KMS.
    - `project_id` - Google Cloud project (application) ID of the deployed Google Cloud application with appropriate access to the Google Cloud KMS.
    - `key_ring_name` - Google Cloud KMS key ring name of the deployed Google Cloud application with appropriate access to the specified Google Cloud KMS.
    - `key_ring_location` - Google Cloud KMS key ring location.
    - `key_name`- Key Identifier of the Google Cloud KMS key encryption key.
    - `application_credentials` - Google Cloud application's service account credentials required to access the specified KMS. It is a JSON file containing an email address and the private key of the service account holder.

    ### Related ONTAP commands

    - `security key-manager external gcp enable`

    ### Learn more

    - `DOC /security/gcp-kms`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def restore(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Restores the keys for an SVM from a configured Google Cloud KMS.

    ### Related ONTAP commands

    - `security key-manager external gcp restore`

    Perform a custom action on this resource which is not a simple CRUD action

    ## Args

    `path`
      The action verb for this request. This will be added as a postfix to the instance location of the resource.
    `body`
      The body of the action request. This should be a Resource instance. The connection and URL will be determined based on the values from this object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class GcpKmsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the GcpKms object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `application_credentials POST PATCH`

    Google Cloud application's service account credentials required to access the specified KMS. It is a JSON file containing an email address and the private key of the service account holder.

    Example: { type: service_account, project_id: project-id, private_key_id: key-id, private_key: -----BEGIN PRIVATE KEY----- private-key -----END PRIVATE KEY----- , client_email: service-account-email, client_id: client-id, auth_uri: https://accounts.google.com/o/oauth2/auth, token_uri: https://accounts.google.com/o/oauth2/token, auth_provider_x509_cert_url: https://www.googleapis.com/oauth2/v1/certs, client_x509_cert_url: https://www.googleapis.com/robot/v1/metadata/x509/service-account-email }

  `key_name GET POST PATCH`

    Key Identifier of Google Cloud KMS key encryption key.

    Example: cryptokey1

  `key_ring_location GET POST`

    Google Cloud KMS key ring location.

    Example: global

  `key_ring_name GET POST`

    Google Cloud KMS key ring name of the deployed Google Cloud application.

    Example: gcpapp1-keyring

  `links GET`

    The links field of the gcp_kms.

  `project_id GET POST`

    Google Cloud project (application) ID of the deployed Google Cloud application that has appropriate access to the Google Cloud KMS.

    Example: gcpapp1

  `scope GET`

    Set to "svm" for interfaces owned by an SVM. Otherwise, set to "cluster".

    Valid choices:

    - svm
    - cluster
  `state GET`

    The state field of the gcp_kms.

  `svm GET POST PATCH`

    The svm field of the gcp_kms.

  `uuid GET`

    A unique identifier for the Google Cloud KMS.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412